@@ -17,6 +17,7 @@ class BoxColliderComponent(ColliderComponent) :
         self.parent = parent
         self.transform = parent.transform
 
+
     def update(self,dt) :
         if (Debug.Debug.ShowCollidersBox):
             pg.draw.rect(Game.get().surface, (0,0,0),((
@@ -27,11 +28,4 @@ class BoxColliderComponent(ColliderComponent) :
 
     def CallCollide(self,o):
         self.parent.onCollision(o)
-    def collide(self,o):
 
-        if (o.transform.position.x+o.transform.scale.x > self.transform.position.x > o.transform.position.x ) or \
-                (self.transform.position.x+self.transform.scale.x > o.transform.position.x > self.transform.position.x ):
-            if (o.transform.position.y + o.transform.scale.y > self.transform.position.y > o.transform.position.y) or \
-                    (self.transform.position.y + self.transform.scale.y > o.transform.position.y > self.transform.position.y):
-                return self.CallCollide(o)
-        return
