@@ -2,11 +2,8 @@ from PyGine.Camera import Camera
 from PyGine.Component import Component
 import PyGine.PyGinegame as Game
 import pygame as pg
-
-
 from PyGine.Transform import Transform
 
-
 class TextComponent(Component) :
     def __init__(self, parent,text = " ",color = (255,0,255)):
         super().__init__(parent)
@@ -23,5 +20,4 @@ class TextComponent(Component) :
         self.textcmp = self.font.render(text,True,self.color)
 
     def update(self,dt):
-        Game.get().surface.blit(self.textcmp,((int(self.transform.position.x + self.parent.transform.position.x - Camera.DX ),int(self.transform.position.y + self.parent.transform.position.y- Camera.DY) ), (int(self.transform.scale.x*Camera.ZX), int(self.transform.scale.y*Camera.ZY))))
-
+        Game.get().surface.blit(self.textcmp,((int(self.transform.position.x + self.parent.transform.position.x - (Camera.DX+Camera.PX) ),int(self.transform.position.y + self.parent.transform.position.y- (Camera.DY+Camera.PY) )), (int(self.transform.scale.x*Camera.ZX), int(self.transform.scale.y*Camera.ZY))))
